@@ -110,7 +110,7 @@ GameView::GameView(QWidget *parent, Game *game, QDockWidget *messagesDock, QDock
 
     m_messagesDock->setWidget(m_msgWidget);
 
-    m_standingsWidget = new StandingsWidget(0);
+    m_standingsWidget = new StandingsWidget(nullptr);
     m_standingsDock->setWidget(m_standingsWidget);
 
     m_gameMessage = new QLabel( this );
@@ -210,7 +210,7 @@ GameView::keyPressEvent( QKeyEvent *e )
         default:
             break;
         }
-        m_mapScene->displayPlanetInfo( NULL );
+        m_mapScene->displayPlanetInfo( nullptr );
         m_mapScene->unselectPlanet();
         m_showInformations = false;
         return;
@@ -238,7 +238,7 @@ GameView::keyPressEvent( QKeyEvent *e )
                 m_mapScene->displayPlanetInfo( p );
                 m_showInformations = false;
             } else {
-                m_mapScene->displayPlanetInfo( NULL );
+                m_mapScene->displayPlanetInfo( nullptr );
                 m_mapScene->selectPlanet(p);
                 planetSelected( p );
             }
@@ -399,7 +399,7 @@ GameView::turn()
 
     m_endTurnBtn->setEnabled(m_guiState == SOURCE_PLANET);
 
-    emit newGUIState( m_guiState );
+    Q_EMIT newGUIState( m_guiState );
 }
 
 void
@@ -434,13 +434,13 @@ GameView::gameMsg(const KLocalizedString &msg, Player *player, Planet *planet,
     if (m_msgWidgetLastTurn < m_game->turnCounter()) {
         m_msgWidgetLastTurn = m_game->turnCounter();
 
-        m_msgWidget->append("<font color=\"gray\">"
+        m_msgWidget->append(QLatin1String("<font color=\"gray\">")
                         + i18n("Turn %1:", m_game->turnCounter())
-                        + "</font>");
+                        + QLatin1String("</font>"));
     }
 
-    m_msgWidget->append("- <font color=\"" + color + "\">"
-                        + colorMsg.toString()+"</font>");
+    m_msgWidget->append(QLatin1String("- <font color=\"") + color + QLatin1String("\">")
+                        + colorMsg.toString()+QLatin1String("</font>"));
     m_msgWidget->moveCursor(QTextCursor::End);
 
     if (isHumanInvolved) {
@@ -587,7 +587,7 @@ GameView::cleanupGame()
 
     m_initCompleted = false;
     m_cleanupNeeded = false;
-    emit newGUIState(m_guiState);
+    Q_EMIT newGUIState(m_guiState);
 }
 
 
